@@ -18,13 +18,14 @@
 """Interact with AWS DataSync, using the AWS ``boto3`` library."""
 
 import time
+import warnings
 from typing import List, Optional
 
 from airflow.exceptions import AirflowBadRequest, AirflowException, AirflowTaskTimeout
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
 
-class AWSDataSyncHook(AwsBaseHook):
+class DataSyncHook(AwsBaseHook):
     """
     Interact with AWS DataSync.
 
@@ -33,7 +34,7 @@ class AWSDataSyncHook(AwsBaseHook):
 
     .. seealso::
         :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
-        :class:`~airflow.providers.amazon.aws.operators.datasync.AWSDataSyncOperator`
+        :class:`~airflow.providers.amazon.aws.operators.datasync.DataSyncOperator`
 
     :param wait_interval_seconds: Time to wait between two
         consecutive calls to check TaskExecution status. Defaults to 30 seconds.
@@ -316,3 +317,18 @@ class AWSDataSyncHook(AwsBaseHook):
         if iterations <= 0:
             raise AirflowTaskTimeout("Max iterations exceeded!")
         raise AirflowException(f"Unknown status: {status}")  # Should never happen
+
+
+class AWSDataSyncHook(DataSyncHook):
+    """
+    This hook is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.hooks.datasync.DataSyncHook`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This hook is deprecated. Please use `airflow.providers.amazon.aws.hooks.datasync.DataSyncHook`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
