@@ -18,12 +18,13 @@
 """Interact with Amazon EKS, using the boto3 library."""
 import base64
 import json
-import re
+import sys
 import tempfile
+import warnings
 from contextlib import contextmanager
 from enum import Enum
 from functools import partial
-from typing import Callable, Dict, List
+from typing import Callable, Dict, List, Optional
 
 import yaml
 from botocore.exceptions import ClientError
@@ -32,10 +33,11 @@ from botocore.signers import RequestSigner
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.utils.json import AirflowJsonEncoder
 
-DEFAULT_CONTEXT_NAME = 'aws'
 DEFAULT_PAGINATION_TOKEN = ''
-DEFAULT_POD_USERNAME = 'aws'
 STS_TOKEN_EXPIRES_IN = 60
+AUTHENTICATION_API_VERSION = "client.authentication.k8s.io/v1alpha1"
+_POD_USERNAME = 'aws'
+_CONTEXT_NAME = 'aws'
 
 
 class ClusterStates(Enum):
@@ -49,6 +51,17 @@ class ClusterStates(Enum):
     NONEXISTENT = "NONEXISTENT"
 
 
+class FargateProfileStates(Enum):
+    """Contains the possible State values of an AWS Fargate profile."""
+
+    CREATING = "CREATING"
+    ACTIVE = "ACTIVE"
+    DELETING = "DELETING"
+    CREATE_FAILED = "CREATE_FAILED"
+    DELETE_FAILED = "DELETE_FAILED"
+    NONEXISTENT = "NONEXISTENT"
+
+
 class NodegroupStates(Enum):
     """Contains the possible State values of an EKS Managed Nodegroup."""
 
@@ -62,7 +75,7 @@ class NodegroupStates(Enum):
     NONEXISTENT = "NONEXISTENT"
 
 
-class EKSHook(AwsBaseHook):
+class EksHook(AwsBaseHook):
     """
     Interact with Amazon EKS, using the boto3 library.
 
@@ -100,16 +113,16 @@ class EKSHook(AwsBaseHook):
             name=name, roleArn=roleArn, resourcesVpcConfig=resourcesVpcConfig, **kwargs
         )
 
-        self.log.info("Created cluster with the name %s.", response.get('cluster').get('name'))
+        self.log.info("Created Amazon EKS cluster with the name %s.", response.get('cluster').get('name'))
         return response
 
     def create_nodegroup(
         self, clusterName: str, nodegroupName: str, subnets: List[str], nodeRole: str, **kwargs
     ) -> Dict:
         """
-        Creates an Amazon EKS Managed Nodegroup for an EKS Cluster.
+        Creates an Amazon EKS managed node group for an Amazon EKS Cluster.
 
-        :param clusterName: The name of the cluster to create the EKS Managed Nodegroup in.
+        :param clusterName: The name of the Amazon EKS cluster to create the EKS Managed Nodegroup in.
         :type clusterName: str
         :param nodegroupName: The unique name to give your managed nodegroup.
         :type nodegroupName: str
@@ -140,12 +153,48 @@ class EKSHook(AwsBaseHook):
         )
 
         self.log.info(
-            "Created a managed nodegroup named %s in cluster %s",
+            "Created an Amazon EKS managed node group named %s in Amazon EKS cluster %s",
             response.get('nodegroup').get('nodegroupName'),
             response.get('nodegroup').get('clusterName'),
         )
         return response
 
+    def create_fargate_profile(
+        self, clusterName: str, fargateProfileName: str, podExecutionRoleArn: str, selectors: List, **kwargs
+    ) -> Dict:
+        """
+        Creates an AWS Fargate profile for an Amazon EKS cluster.
+
+        :param clusterName: The name of the Amazon EKS cluster to apply the Fargate profile to.
+        :type clusterName: str
+        :param fargateProfileName: The name of the Fargate profile.
+        :type fargateProfileName: str
+        :param podExecutionRoleArn: The Amazon Resource Name (ARN) of the pod execution role to
+            use for pods that match the selectors in the Fargate profile.
+        :type podExecutionRoleArn: str
+        :param selectors: The selectors to match for pods to use this Fargate profile.
+        :type selectors: List
+
+        :return: Returns descriptive information about the created Fargate profile.
+        :rtype: Dict
+        """
+        eks_client = self.conn
+
+        response = eks_client.create_fargate_profile(
+            clusterName=clusterName,
+            fargateProfileName=fargateProfileName,
+            podExecutionRoleArn=podExecutionRoleArn,
+            selectors=selectors,
+            **kwargs,
+        )
+
+        self.log.info(
+            "Created AWS Fargate profile with the name %s for Amazon EKS cluster %s.",
+            response.get('fargateProfile').get('fargateProfileName'),
+            response.get('fargateProfile').get('clusterName'),
+        )
+        return response
+
     def delete_cluster(self, name: str) -> Dict:
         """
         Deletes the Amazon EKS Cluster control plane.
@@ -160,12 +209,12 @@ class EKSHook(AwsBaseHook):
 
         response = eks_client.delete_cluster(name=name)
 
-        self.log.info("Deleted cluster with the name %s.", response.get('cluster').get('name'))
+        self.log.info("Deleted Amazon EKS cluster with the name %s.", response.get('cluster').get('name'))
         return response
 
     def delete_nodegroup(self, clusterName: str, nodegroupName: str) -> Dict:
         """
-        Deletes an Amazon EKS Nodegroup from a specified cluster.
+        Deletes an Amazon EKS managed node group from a specified cluster.
 
         :param clusterName: The name of the Amazon EKS Cluster that is associated with your nodegroup.
         :type clusterName: str
@@ -180,12 +229,37 @@ class EKSHook(AwsBaseHook):
         response = eks_client.delete_nodegroup(clusterName=clusterName, nodegroupName=nodegroupName)
 
         self.log.info(
-            "Deleted nodegroup named %s from cluster %s.",
+            "Deleted Amazon EKS managed node group named %s from Amazon EKS cluster %s.",
             response.get('nodegroup').get('nodegroupName'),
             response.get('nodegroup').get('clusterName'),
         )
         return response
 
+    def delete_fargate_profile(self, clusterName: str, fargateProfileName: str) -> Dict:
+        """
+        Deletes an AWS Fargate profile from a specified Amazon EKS cluster.
+
+        :param clusterName: The name of the Amazon EKS cluster associated with the Fargate profile to delete.
+        :type clusterName: str
+        :param fargateProfileName: The name of the Fargate profile to delete.
+        :type fargateProfileName: str
+
+        :return: Returns descriptive information about the deleted Fargate profile.
+        :rtype: Dict
+        """
+        eks_client = self.conn
+
+        response = eks_client.delete_fargate_profile(
+            clusterName=clusterName, fargateProfileName=fargateProfileName
+        )
+
+        self.log.info(
+            "Deleted AWS Fargate profile with the name %s from Amazon EKS cluster %s.",
+            response.get('fargateProfile').get('fargateProfileName'),
+            response.get('fargateProfile').get('clusterName'),
+        )
+        return response
+
     def describe_cluster(self, name: str, verbose: bool = False) -> Dict:
         """
         Returns descriptive information about an Amazon EKS Cluster.
@@ -202,15 +276,17 @@ class EKSHook(AwsBaseHook):
 
         response = eks_client.describe_cluster(name=name)
 
-        self.log.info("Retrieved details for cluster named %s.", response.get('cluster').get('name'))
+        self.log.info(
+            "Retrieved details for Amazon EKS cluster named %s.", response.get('cluster').get('name')
+        )
         if verbose:
             cluster_data = response.get('cluster')
-            self.log.info("Cluster Details: %s", json.dumps(cluster_data, cls=AirflowJsonEncoder))
+            self.log.info("Amazon EKS cluster details: %s", json.dumps(cluster_data, cls=AirflowJsonEncoder))
         return response
 
     def describe_nodegroup(self, clusterName: str, nodegroupName: str, verbose: bool = False) -> Dict:
         """
-        Returns descriptive information about an Amazon EKS Nodegroup.
+        Returns descriptive information about an Amazon EKS managed node group.
 
         :param clusterName: The name of the Amazon EKS Cluster associated with the nodegroup.
         :type clusterName: str
@@ -227,13 +303,50 @@ class EKSHook(AwsBaseHook):
         response = eks_client.describe_nodegroup(clusterName=clusterName, nodegroupName=nodegroupName)
 
         self.log.info(
-            "Retrieved details for nodegroup named %s in cluster %s.",
+            "Retrieved details for Amazon EKS managed node group named %s in Amazon EKS cluster %s.",
             response.get('nodegroup').get('nodegroupName'),
             response.get('nodegroup').get('clusterName'),
         )
         if verbose:
             nodegroup_data = response.get('nodegroup')
-            self.log.info("Nodegroup Details: %s", json.dumps(nodegroup_data, cls=AirflowJsonEncoder))
+            self.log.info(
+                "Amazon EKS managed node group details: %s",
+                json.dumps(nodegroup_data, cls=AirflowJsonEncoder),
+            )
+        return response
+
+    def describe_fargate_profile(
+        self, clusterName: str, fargateProfileName: str, verbose: bool = False
+    ) -> Dict:
+        """
+        Returns descriptive information about an AWS Fargate profile.
+
+        :param clusterName: The name of the Amazon EKS Cluster associated with the Fargate profile.
+        :type clusterName: str
+        :param fargateProfileName: The name of the Fargate profile to describe.
+        :type fargateProfileName: str
+        :param verbose: Provides additional logging if set to True.  Defaults to False.
+        :type verbose: bool
+
+        :return: Returns descriptive information about an AWS Fargate profile.
+        :rtype: Dict
+        """
+        eks_client = self.conn
+
+        response = eks_client.describe_fargate_profile(
+            clusterName=clusterName, fargateProfileName=fargateProfileName
+        )
+
+        self.log.info(
+            "Retrieved details for AWS Fargate profile named %s in Amazon EKS cluster %s.",
+            response.get('fargateProfile').get('fargateProfileName'),
+            response.get('fargateProfile').get('clusterName'),
+        )
+        if verbose:
+            fargate_profile_data = response.get('fargateProfile')
+            self.log.info(
+                "AWS Fargate profile details: %s", json.dumps(fargate_profile_data, cls=AirflowJsonEncoder)
+            )
         return response
 
     def get_cluster_state(self, clusterName: str) -> ClusterStates:
@@ -254,9 +367,35 @@ class EKSHook(AwsBaseHook):
             if ex.response.get("Error").get("Code") == "ResourceNotFoundException":
                 return ClusterStates.NONEXISTENT
 
+    def get_fargate_profile_state(self, clusterName: str, fargateProfileName: str) -> FargateProfileStates:
+        """
+        Returns the current status of a given AWS Fargate profile.
+
+        :param clusterName: The name of the Amazon EKS Cluster associated with the Fargate profile.
+        :type clusterName: str
+        :param fargateProfileName: The name of the Fargate profile to check.
+        :type fargateProfileName: str
+
+        :return: Returns the current status of a given AWS Fargate profile.
+        :rtype: AWS FargateProfileStates
+        """
+        eks_client = self.conn
+
+        try:
+            return FargateProfileStates(
+                eks_client.describe_fargate_profile(
+                    clusterName=clusterName, fargateProfileName=fargateProfileName
+                )
+                .get('fargateProfile')
+                .get('status')
+            )
+        except ClientError as ex:
+            if ex.response.get("Error").get("Code") == "ResourceNotFoundException":
+                return FargateProfileStates.NONEXISTENT
+
     def get_nodegroup_state(self, clusterName: str, nodegroupName: str) -> NodegroupStates:
         """
-        Returns the current status of a given Amazon EKS Nodegroup.
+        Returns the current status of a given Amazon EKS managed node group.
 
         :param clusterName: The name of the Amazon EKS Cluster associated with the nodegroup.
         :type clusterName: str
@@ -292,9 +431,9 @@ class EKSHook(AwsBaseHook):
         :rtype: List
         """
         eks_client = self.conn
-        api_call = partial(eks_client.list_clusters)
+        list_cluster_call = partial(eks_client.list_clusters)
 
-        return self._list_all(api_call=api_call, response_key="clusters", verbose=verbose)
+        return self._list_all(api_call=list_cluster_call, response_key="clusters", verbose=verbose)
 
     def list_nodegroups(
         self,
@@ -302,7 +441,7 @@ class EKSHook(AwsBaseHook):
         verbose: bool = False,
     ) -> List:
         """
-        Lists all Amazon EKS Nodegroups associated with the specified cluster.
+        Lists all Amazon EKS managed node groups associated with the specified cluster.
 
         :param clusterName: The name of the Amazon EKS Cluster containing nodegroups to list.
         :type clusterName: str
@@ -313,9 +452,32 @@ class EKSHook(AwsBaseHook):
         :rtype: List
         """
         eks_client = self.conn
-        api_call = partial(eks_client.list_nodegroups, clusterName=clusterName)
+        list_nodegroups_call = partial(eks_client.list_nodegroups, clusterName=clusterName)
 
-        return self._list_all(api_call=api_call, response_key="nodegroups", verbose=verbose)
+        return self._list_all(api_call=list_nodegroups_call, response_key="nodegroups", verbose=verbose)
+
+    def list_fargate_profiles(
+        self,
+        clusterName: str,
+        verbose: bool = False,
+    ) -> List:
+        """
+        Lists all AWS Fargate profiles associated with the specified cluster.
+
+        :param clusterName: The name of the Amazon EKS Cluster containing Fargate profiles to list.
+        :type clusterName: str
+        :param verbose: Provides additional logging if set to True.  Defaults to False.
+        :type verbose: bool
+
+        :return: A list of Fargate profile names within a given cluster.
+        :rtype: List
+        """
+        eks_client = self.conn
+        list_fargate_profiles_call = partial(eks_client.list_fargate_profiles, clusterName=clusterName)
+
+        return self._list_all(
+            api_call=list_fargate_profiles_call, response_key="fargateProfileNames", verbose=verbose
+        )
 
     def _list_all(self, api_call: Callable, response_key: str, verbose: bool) -> List:
         """
@@ -351,21 +513,31 @@ class EKSHook(AwsBaseHook):
         self,
         eks_cluster_name: str,
         pod_namespace: str,
-        pod_username: str = DEFAULT_POD_USERNAME,
-        pod_context: str = DEFAULT_CONTEXT_NAME,
+        pod_username: Optional[str] = None,
+        pod_context: Optional[str] = None,
     ) -> str:
         """
         Writes the kubeconfig file given an EKS Cluster.
 
-        :param eks_cluster_name: The name of the cluster to create the EKS Managed Nodegroup in.
+        :param eks_cluster_name: The name of the cluster to generate kubeconfig file for.
         :type eks_cluster_name: str
         :param pod_namespace: The namespace to run within kubernetes.
         :type pod_namespace: str
-        :param pod_username: The username under which to execute the pod.
-        :type pod_username: str
-        :param pod_context: The name of the context access parameters to use.
-        :type pod_context: str
         """
+        if pod_username:
+            warnings.warn(
+                "This pod_username parameter is deprecated, because changing the value does not make any "
+                "visible changes to the user.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        if pod_context:
+            warnings.warn(
+                "This pod_context parameter is deprecated, because changing the value does not make any "
+                "visible changes to the user.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         # Set up the client
         eks_client = self.conn
 
@@ -374,8 +546,6 @@ class EKSHook(AwsBaseHook):
         cluster_cert = cluster["cluster"]["certificateAuthority"]["data"]
         cluster_ep = cluster["cluster"]["endpoint"]
 
-        token = self._fetch_sts_token(cluster_id=eks_cluster_name)
-
         cluster_config = {
             "apiVersion": "v1",
             "kind": "Config",
@@ -390,23 +560,48 @@ class EKSHook(AwsBaseHook):
                     "context": {
                         "cluster": eks_cluster_name,
                         "namespace": pod_namespace,
-                        "user": pod_username,
+                        "user": _POD_USERNAME,
                     },
-                    "name": pod_context,
+                    "name": _CONTEXT_NAME,
                 }
             ],
-            "current-context": pod_context,
+            "current-context": _CONTEXT_NAME,
             "preferences": {},
             "users": [
                 {
-                    "name": pod_username,
+                    "name": _POD_USERNAME,
                     "user": {
-                        "token": token,
+                        "exec": {
+                            "apiVersion": AUTHENTICATION_API_VERSION,
+                            "command": sys.executable,
+                            "args": [
+                                "-m",
+                                "airflow.providers.amazon.aws.utils.eks_get_token",
+                                *(
+                                    ["--region-name", self.region_name]
+                                    if self.region_name is not None
+                                    else []
+                                ),
+                                *(
+                                    ["--aws-conn-id", self.aws_conn_id]
+                                    if self.aws_conn_id is not None
+                                    else []
+                                ),
+                                "--cluster-name",
+                                eks_cluster_name,
+                            ],
+                            "env": [
+                                {
+                                    "name": "AIRFLOW__LOGGING__LOGGING_LEVEL",
+                                    "value": "fatal",
+                                }
+                            ],
+                            "interactiveMode": "Never",
+                        }
                     },
                 }
             ],
         }
-
         config_text = yaml.dump(cluster_config, default_flow_style=False)
 
         with tempfile.NamedTemporaryFile(mode='w') as config_file:
@@ -414,7 +609,7 @@ class EKSHook(AwsBaseHook):
             config_file.flush()
             yield config_file.name
 
-    def _fetch_sts_token(self, cluster_id: str) -> str:
+    def fetch_access_token_for_cluster(self, eks_cluster_name: str) -> str:
         session = self.get_session()
         service_id = self.conn.meta.service_model.service_id
         sts_url = (
@@ -434,7 +629,7 @@ class EKSHook(AwsBaseHook):
             'method': 'GET',
             'url': sts_url,
             'body': {},
-            'headers': {'x-k8s-aws-id': cluster_id},
+            'headers': {'x-k8s-aws-id': eks_cluster_name},
             'context': {},
         }
 
@@ -448,4 +643,19 @@ class EKSHook(AwsBaseHook):
         base64_url = base64.urlsafe_b64encode(signed_url.encode('utf-8')).decode('utf-8')
 
         # remove any base64 encoding padding:
-        return 'k8s-aws-v1.' + re.sub(r'=*', '', base64_url)
+        return 'k8s-aws-v1.' + base64_url.rstrip("=")
+
+
+class EKSHook(EksHook):
+    """
+    This hook is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.hooks.eks.EksHook`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This hook is deprecated. " "Please use `airflow.providers.amazon.aws.hooks.eks.EksHook`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
