@@ -16,10 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 import os
+import sys
 
-try:
+if sys.version_info >= (3, 8):
     from functools import cached_property
-except ImportError:
+else:
     from cached_property import cached_property
 
 from airflow.configuration import conf
@@ -50,7 +51,7 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
             from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 
             return S3Hook(remote_conn_id, transfer_config_args={"use_threads": False})
-        except Exception as e:  # pylint: disable=broad-except
+        except Exception as e:
             self.log.exception(
                 'Could not create an S3Hook with connection id "%s". '
                 'Please make sure that apache-airflow[aws] is installed and '
@@ -119,7 +120,7 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
 
         try:
             log_exists = self.s3_log_exists(remote_loc)
-        except Exception as error:  # pylint: disable=broad-except
+        except Exception as error:
             self.log.exception("Failed to verify remote log exists %s.", remote_loc)
             log = f'*** Failed to verify remote log exists {remote_loc}.\n{error}\n'
 
@@ -159,7 +160,7 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
         """
         try:
             return self.hook.read_key(remote_log_location)
-        except Exception as error:  # pylint: disable=broad-except
+        except Exception as error:
             msg = f'Could not read logs from {remote_log_location} with error: {error}'
             self.log.exception(msg)
             # return error if needed
@@ -184,7 +185,7 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
             if append and self.s3_log_exists(remote_log_location):
                 old_log = self.s3_read(remote_log_location)
                 log = '\n'.join([old_log, log]) if old_log else log
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             self.log.exception('Could not verify previous log to append')
 
         try:
@@ -194,5 +195,5 @@ class S3TaskHandler(FileTaskHandler, LoggingMixin):
                 replace=True,
                 encrypt=conf.getboolean('logging', 'ENCRYPT_S3_LOGS'),
             )
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             self.log.exception('Could not write logs to %s', remote_log_location)
