@@ -16,10 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module allows you to transfer mail attachments from a mail server into s3 bucket."""
+from typing import TYPE_CHECKING, Sequence
+
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.imap.hooks.imap import ImapHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class ImapAttachmentToS3Operator(BaseOperator):
     """
@@ -48,7 +53,7 @@ class ImapAttachmentToS3Operator(BaseOperator):
     :type s3_conn_id: str
     """
 
-    template_fields = ('imap_attachment_name', 's3_key', 'imap_mail_filter')
+    template_fields: Sequence[str] = ('imap_attachment_name', 's3_key', 'imap_mail_filter')
 
     def __init__(
         self,
@@ -73,7 +78,7 @@ class ImapAttachmentToS3Operator(BaseOperator):
         self.imap_conn_id = imap_conn_id
         self.s3_conn_id = s3_conn_id
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         """
         This function executes the transfer from the email server (via imap) into s3.
 
