@@ -16,13 +16,16 @@
 # specific language governing permissions and limitations
 # under the License.
 """Transfers data from AWS Redshift into a S3 Bucket."""
-from typing import Iterable, List, Mapping, Optional, Union
+from typing import TYPE_CHECKING, Iterable, List, Mapping, Optional, Sequence, Union
 
 from airflow.models import BaseOperator
-from airflow.providers.amazon.aws.hooks.redshift import RedshiftSQLHook
+from airflow.providers.amazon.aws.hooks.redshift_sql import RedshiftSQLHook
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.amazon.aws.utils.redshift import build_credentials_block
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class RedshiftToS3Operator(BaseOperator):
     """
@@ -73,8 +76,15 @@ class RedshiftToS3Operator(BaseOperator):
     :type table_as_file_name: bool
     """
 
-    template_fields = ('s3_bucket', 's3_key', 'schema', 'table', 'unload_options', 'select_query')
-    template_ext = ('.sql',)
+    template_fields: Sequence[str] = (
+        's3_bucket',
+        's3_key',
+        'schema',
+        'table',
+        'unload_options',
+        'select_query',
+    )
+    template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'select_query': 'sql'}
     ui_color = '#ededed'
 
@@ -83,9 +93,9 @@ class RedshiftToS3Operator(BaseOperator):
         *,
         s3_bucket: str,
         s3_key: str,
-        schema: str = None,
-        table: str = None,
-        select_query: str = None,
+        schema: Optional[str] = None,
+        table: Optional[str] = None,
+        select_query: Optional[str] = None,
         redshift_conn_id: str = 'redshift_default',
         aws_conn_id: str = 'aws_default',
         verify: Optional[Union[bool, str]] = None,
@@ -135,7 +145,7 @@ class RedshiftToS3Operator(BaseOperator):
                     {unload_options};
         """
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         redshift_hook = RedshiftSQLHook(redshift_conn_id=self.redshift_conn_id)
         conn = S3Hook.get_connection(conn_id=self.aws_conn_id)
 
