@@ -17,17 +17,25 @@
 # under the License.
 
 from tempfile import NamedTemporaryFile
+from typing import TYPE_CHECKING, Sequence
 from urllib.parse import urlparse
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.ssh.hooks.ssh import SSHHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class S3ToSFTPOperator(BaseOperator):
     """
     This operator enables the transferring of files from S3 to a SFTP server.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:S3ToSFTPOperator`
+
     :param sftp_conn_id: The sftp connection id. The name or identifier for
         establishing a connection to the SFTP server.
     :type sftp_conn_id: str
@@ -45,7 +53,7 @@ class S3ToSFTPOperator(BaseOperator):
     :type s3_key: str
     """
 
-    template_fields = ('s3_key', 'sftp_path')
+    template_fields: Sequence[str] = ('s3_key', 'sftp_path')
 
     def __init__(
         self,
@@ -70,7 +78,7 @@ class S3ToSFTPOperator(BaseOperator):
         parsed_s3_key = urlparse(s3_key)
         return parsed_s3_key.path.lstrip('/')
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         self.s3_key = self.get_s3_key(self.s3_key)
         ssh_hook = SSHHook(ssh_conn_id=self.sftp_conn_id)
         s3_hook = S3Hook(self.s3_conn_id)
